@@ -8,6 +8,7 @@ from math import pi
 from compas.geometry import centroid_points
 
 from compas.datastructures.mesh._mesh import Mesh
+from compas.datastructures.mesh.operations import mesh_split_edge
 
 
 __all__ = [
@@ -61,15 +62,16 @@ class SubdMesh(Mesh):
 # any subd algorithm should return a new subd mesh, leaving the control mesh intact
 
 
-def mesh_subdivide(mesh, scheme='tri', **options):
+def mesh_subdivide(mesh, scheme='catmullclark', **options):
     """Subdivide the input mesh.
 
     Parameters
     ----------
     mesh : Mesh
         A mesh object.
-    scheme : {'tri', 'corner', 'catmullclark', 'doosabin'}.
+    scheme : {'tri', 'corner', 'catmullclark', 'doosabin'}, optional
         The scheme according to which the mesh should be subdivided.
+        Default is ``'catmullclark'``.
     options : dict
         Optional additional keyword arguments.
 
@@ -134,7 +136,7 @@ def mesh_subdivide_quad(mesh, k=1):
         subd = mesh.copy()
 
         for u, v in list(subd.edges()):
-            subd.split_edge(u, v, allow_boundary=True)
+            mesh_split_edge(subd, u, v, allow_boundary=True)
 
         for fkey in mesh.faces():
 
@@ -188,7 +190,7 @@ def mesh_subdivide_corner(mesh, k=1):
 
         # split every edge
         for u, v in list(subd.edges()):
-            subd.split_edge(u, v, allow_boundary=True)
+            mesh_split_edge(subd, u, v, allow_boundary=True)
 
         # create 4 new faces for every old face
         for fkey in mesh.faces():
@@ -337,7 +339,7 @@ def mesh_subdivide_catmullclark(mesh, k=1, fixed=None):
 
         for u, v in mesh.edges():
 
-            w = subd.split_edge(u, v, allow_boundary=True)
+            w = mesh_split_edge(subd, u, v, allow_boundary=True)
 
             # document why this is necessary
             # everything else in this loop is just quad subdivision
