@@ -1,6 +1,6 @@
 """
 ********************************************************************************
-compas.files
+files
 ********************************************************************************
 
 .. currentmodule:: compas.files
